==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/ConsoleAuthenticationFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ConsoleAuthenticationFluentImpl<A extends io.fabric8.openshift.api.model.ConsoleAuthenticationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ConsoleAuthenticationFluent<A>{
  public ConsoleAuthenticationFluentImpl() {
  }
  public ConsoleAuthenticationFluentImpl(io.fabric8.openshift.api.model.ConsoleAuthentication instance) {
    this.withLogoutRedirect(instance.getLogoutRedirect()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String logoutRedirect;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getLogoutRedirect() {
    return this.logoutRedirect;
  }
  public A withLogoutRedirect(java.lang.String logoutRedirect) {
    this.logoutRedirect=logoutRedirect; return (A) this;
  }
  public java.lang.Boolean hasLogoutRedirect() {
    return this.logoutRedirect != null;
  }
  
  /**
   * Method is deprecated. use withLogoutRedirect instead.
   */
  @java.lang.Deprecated
  public A withNewLogoutRedirect(java.lang.String arg0) {
    return (A)withLogoutRedirect(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleAuthenticationFluentImpl that = (ConsoleAuthenticationFluentImpl) o;
    if (logoutRedirect != null ? !logoutRedirect.equals(that.logoutRedirect) :that.logoutRedirect != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(logoutRedirect,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/ConsoleAuthenticationFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ConsoleAuthenticationFluentImpl<A extends io.fabric8.openshift.api.model.ConsoleAuthenticationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ConsoleAuthenticationFluent<A>{
  public ConsoleAuthenticationFluentImpl() {
  }
  public ConsoleAuthenticationFluentImpl(io.fabric8.openshift.api.model.ConsoleAuthentication instance) {
    this.withLogoutRedirect(instance.getLogoutRedirect()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String logoutRedirect;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getLogoutRedirect() {
    return this.logoutRedirect;
  }
  public A withLogoutRedirect(java.lang.String logoutRedirect) {
    this.logoutRedirect=logoutRedirect; return (A) this;
  }
  public java.lang.Boolean hasLogoutRedirect() {
    return this.logoutRedirect != null;
  }
  
  /**
   * Method is deprecated. use withLogoutRedirect instead.
   */
  @java.lang.Deprecated
  public A withNewLogoutRedirect(java.lang.String arg0) {
    return (A)withLogoutRedirect(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleAuthenticationFluentImpl that = (ConsoleAuthenticationFluentImpl) o;
    if (logoutRedirect != null ? !logoutRedirect.equals(that.logoutRedirect) :that.logoutRedirect != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(logoutRedirect,  additionalProperties,  super.hashCode());
  }
  
}
